import { BpmnType } from '../constants';
import { MessageEventDefinition } from '../events/index';
import { Activity } from './activity';
/**
 * Describes a BPMN SendTask.
 *
 * A send task sends a user defined message to a ReceiveTask.
 *
 * In contrast to an Intermediate Message, a SendTask will block
 * the execution of the process, until a confirmation message from a
 * ReceiveTask was fetched.
 */
export declare class SendTask extends Activity {
    get bpmnType(): BpmnType;
    /**
     * The interval in which a SendTask should re-send its message.
     * Defaults to 500ms.
     */
    retryIntervalInMs: number;
    /**
     * Optional: The maximum number of retries.
     * If not set, the SendTask will keep sending its message indefinetly, until it receives a response.
     */
    maxRetries?: number;
    /**
     * This property contains the user defined message which should be
     * send to a receive task.
     */
    messageEventDefinition: MessageEventDefinition;
}
